@@ -1,5 +1,6 @@
 import re
 
+
 def parse_content(content: str, matcher: str):
     """
     split content into attributes and content text
@@ -13,14 +14,14 @@ def parse_content(content: str, matcher: str):
     """
 
     matchmaker = re.compile(matcher, flags=re.M)
-    split_content = content.split('\n\n', maxsplit=1)
+    split_content = content.split("\n\n", maxsplit=1)
     attr_section = split_content[0]
 
     if len(split_content) == 2:
         base_content = split_content[1]
 
     else:
-        base_content = ''
+        base_content = ""
 
     parsed_attrs = re.split(matchmaker, attr_section)
     content = base_content.strip()
